@@ -74,7 +74,7 @@ class STManager(BulkManager):
     tbl_name = "buckeyebrowser_segmenttoken"
     cols = ['id','WordToken_id','SegmentType_id','Begin','End']
 
-class Speaker(models.Model):
+class Speaker(caching.base.CachingMixin,models.Model):
     Number = models.CharField(max_length=3)
     Gender = models.CharField(max_length=10)
     Age = models.CharField(max_length=10)
@@ -84,6 +84,8 @@ class Speaker(models.Model):
     F2center = models.FloatField(blank=True,null=True)
     AvgSpeakingRate = models.FloatField(blank=True,null=True)
 
+    objects = caching.base.CachingManager()
+
     def __unicode__(self):
         return u'%s' % (self.Number,)
 
@@ -164,10 +166,12 @@ Group by StressVowel) AS averages""",[self.pk])
 
 
 
-class Dialog(models.Model):
+class Dialog(caching.base.CachingMixin,models.Model):
     Speaker = models.ForeignKey(Speaker)
     Number = models.CharField(max_length=10)
 
+    objects = caching.base.CachingManager()
+
     def __unicode__(self):
         return u'%s%s' % (self.Speaker,self.Number)
 
@@ -220,13 +224,15 @@ class Dialog(models.Model):
 
 
 
-class SegmentType(models.Model):
+class SegmentType(caching.base.CachingMixin,models.Model):
     Label = models.CharField(max_length=10)
     Syllabic = models.BooleanField()
     Obstruent = models.BooleanField()
     Nasal = models.BooleanField()
     Vowel = models.BooleanField()
 
+    objects = caching.base.CachingManager()
+
     def isSyllabic(self):
         return self.Syllabic
 
@@ -247,12 +253,14 @@ class SegmentType(models.Model):
         durs = [x.End - x.Begin for x in qs]
         return sum(durs)/float(len(durs))
 
-class Underlying(models.Model):
+class Underlying(caching.base.CachingMixin,models.Model):
     WordType = models.ForeignKey('WordType')
     SegmentType = models.ForeignKey(SegmentType)
     Ordering = models.IntegerField()
     Stressed = models.IntegerField(blank=True,null=True)
 
+    objects = caching.base.CachingManager()
+
     def getStrTrans(self):
         if self.Stressed is None:
             return str(self.SegmentType).upper()
@@ -261,14 +269,14 @@ class Underlying(models.Model):
     class Meta:
         ordering = ['Ordering']
 
-class SegmentToken(models.Model):
+class SegmentToken(caching.base.CachingMixin,models.Model):
     WordToken = models.ForeignKey('WordToken')
     SegmentType = models.ForeignKey(SegmentType)
     Begin = models.FloatField()
     End = models.FloatField()
     Stressed = models.NullBooleanField()
 
-    objects = STManager()
+    objects = caching.base.CachingManager()
 
     def __unicode__(self):
         return u'%s' % unicode(self.SegmentType)
@@ -279,11 +287,13 @@ class SegmentToken(models.Model):
     def getEnd(self):
         return self.End
 
-class Category(models.Model):
+class Category(caching.base.CachingMixin,models.Model):
     Label = models.CharField(max_length=10)
     Description = models.CharField(max_length=250)
     CategoryType = models.CharField('Category type',max_length=100)
 
+    objects = caching.base.CachingManager()
+
     def isContent(self):
         if self.CategoryType == 'Content':
             return True
@@ -292,12 +302,14 @@ class Category(models.Model):
     def __unicode__(self):
         return u'%s' % self.Label
 
-class PrevCondProbs(models.Model):
+class PrevCondProbs(caching.base.CachingMixin,models.Model):
     ActWord = models.ForeignKey('WordType',related_name='prevactword')
     PreviousWord = models.ForeignKey('WordType',related_name='prevword')
     Count = models.IntegerField(blank=True,null=True)
     Prob = models.FloatField(blank=True,null=True)
 
+    objects = caching.base.CachingManager()
+
     def getProb(self):
         if self.Prob is not None:
             return self.Prob
@@ -310,12 +322,14 @@ class PrevCondProbs(models.Model):
         self.save()
         return self.Prob
 
-class FollCondProbs(models.Model):
+class FollCondProbs(caching.base.CachingMixin,models.Model):
     ActWord = models.ForeignKey('WordType',related_name='follactword')
     FollowingWord = models.ForeignKey('WordType',related_name='follword')
     Count = models.IntegerField(blank=True,null=True)
     Prob = models.FloatField(blank=True,null=True)
 
+    objects = caching.base.CachingManager()
+
     def getProb(self):
         if self.Prob is not None:
             return self.Prob
@@ -328,7 +342,7 @@ class FollCondProbs(models.Model):
         self.save()
         return self.Prob
 
-class WordType(models.Model):
+class WordType(caching.base.CachingMixin,models.Model):
     Label = models.CharField(max_length=250)
     UR = models.ManyToManyField(SegmentType,through=Underlying)
     Count = models.IntegerField(blank=True,null=True)
@@ -341,6 +355,8 @@ class WordType(models.Model):
     CVSkel = models.CharField(max_length=100,blank=True,null=True)
     StressVowel = models.CharField(max_length=10,blank=True,null=True)
 
+    objects = caching.base.CachingManager()
+
     def __unicode__(self):
         return u'%s' % self.Label
 
